Class: Google::Apis::ServicenetworkingV1beta::BatchingConfigProto

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

BatchingConfigProto defines the batching configuration for an API method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchingConfigProto

Returns a new instance of BatchingConfigProto.



681
682
683
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 681

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#batch_descriptorGoogle::Apis::ServicenetworkingV1beta::BatchingDescriptorProto

BatchingDescriptorProto specifies the fields of the request message to be used for batching, and, optionally, the fields of the response message to be used for demultiplexing. Corresponds to the JSON property batchDescriptor



672
673
674
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 672

def batch_descriptor
  @batch_descriptor
end

#thresholdsGoogle::Apis::ServicenetworkingV1beta::BatchingSettingsProto

BatchingSettingsProto specifies a set of batching thresholds, each of which acts as a trigger to send a batch of messages as a request. At least one threshold must be positive nonzero. Corresponds to the JSON property thresholds



679
680
681
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 679

def thresholds
  @thresholds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



686
687
688
689
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 686

def update!(**args)
  @batch_descriptor = args[:batch_descriptor] if args.key?(:batch_descriptor)
  @thresholds = args[:thresholds] if args.key?(:thresholds)
end