Class: Google::Apis::ServicenetworkingV1beta::ClientLibrarySettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

Details about how and where to publish client libraries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClientLibrarySettings

Returns a new instance of ClientLibrarySettings.



938
939
940
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 938

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpp_settingsGoogle::Apis::ServicenetworkingV1beta::CppSettings

Settings for C++ client libraries. Corresponds to the JSON property cppSettings



882
883
884
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 882

def cpp_settings
  @cpp_settings
end

#dotnet_settingsGoogle::Apis::ServicenetworkingV1beta::DotnetSettings

Settings for Dotnet client libraries. Corresponds to the JSON property dotnetSettings



887
888
889
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 887

def dotnet_settings
  @dotnet_settings
end

#go_settingsGoogle::Apis::ServicenetworkingV1beta::GoSettings

Settings for Go client libraries. Corresponds to the JSON property goSettings



892
893
894
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 892

def go_settings
  @go_settings
end

#java_settingsGoogle::Apis::ServicenetworkingV1beta::JavaSettings

Settings for Java client libraries. Corresponds to the JSON property javaSettings



897
898
899
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 897

def java_settings
  @java_settings
end

#launch_stageString

Launch stage of this version of the API. Corresponds to the JSON property launchStage

Returns:

  • (String)


902
903
904
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 902

def launch_stage
  @launch_stage
end

#node_settingsGoogle::Apis::ServicenetworkingV1beta::NodeSettings

Settings for Node client libraries. Corresponds to the JSON property nodeSettings



907
908
909
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 907

def node_settings
  @node_settings
end

#php_settingsGoogle::Apis::ServicenetworkingV1beta::PhpSettings

Settings for Php client libraries. Corresponds to the JSON property phpSettings



912
913
914
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 912

def php_settings
  @php_settings
end

#python_settingsGoogle::Apis::ServicenetworkingV1beta::PythonSettings

Settings for Python client libraries. Corresponds to the JSON property pythonSettings



917
918
919
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 917

def python_settings
  @python_settings
end

#rest_numeric_enumsBoolean Also known as: rest_numeric_enums?

When using transport=rest, the client request will encode enums as numbers rather than strings. Corresponds to the JSON property restNumericEnums

Returns:

  • (Boolean)


923
924
925
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 923

def rest_numeric_enums
  @rest_numeric_enums
end

#ruby_settingsGoogle::Apis::ServicenetworkingV1beta::RubySettings

Settings for Ruby client libraries. Corresponds to the JSON property rubySettings



929
930
931
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 929

def ruby_settings
  @ruby_settings
end

#versionString

Version of the API to apply these settings to. This is the full protobuf package for the API, ending in the version element. Examples: "google.cloud. speech.v1" and "google.spanner.admin.database.v1". Corresponds to the JSON property version

Returns:

  • (String)


936
937
938
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 936

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



943
944
945
946
947
948
949
950
951
952
953
954
955
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 943

def update!(**args)
  @cpp_settings = args[:cpp_settings] if args.key?(:cpp_settings)
  @dotnet_settings = args[:dotnet_settings] if args.key?(:dotnet_settings)
  @go_settings = args[:go_settings] if args.key?(:go_settings)
  @java_settings = args[:java_settings] if args.key?(:java_settings)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @node_settings = args[:node_settings] if args.key?(:node_settings)
  @php_settings = args[:php_settings] if args.key?(:php_settings)
  @python_settings = args[:python_settings] if args.key?(:python_settings)
  @rest_numeric_enums = args[:rest_numeric_enums] if args.key?(:rest_numeric_enums)
  @ruby_settings = args[:ruby_settings] if args.key?(:ruby_settings)
  @version = args[:version] if args.key?(:version)
end