Class: Google::Apis::ServicenetworkingV1beta::CommonLanguageSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

Required information for every language.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommonLanguageSettings

Returns a new instance of CommonLanguageSettings.



1010
1011
1012
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1010

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationsArray<String>

The destination where API teams want this client library to be published. Corresponds to the JSON property destinations

Returns:

  • (Array<String>)


996
997
998
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 996

def destinations
  @destinations
end

#reference_docs_uriString

Link to automatically generated reference documentation. Example: https:// cloud.google.com/nodejs/docs/reference/asset/latest Corresponds to the JSON property referenceDocsUri

Returns:

  • (String)


1002
1003
1004
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1002

def reference_docs_uri
  @reference_docs_uri
end

#selective_gapic_generationGoogle::Apis::ServicenetworkingV1beta::SelectiveGapicGeneration

This message is used to configure the generation of a subset of the RPCs in a service for client libraries. Corresponds to the JSON property selectiveGapicGeneration



1008
1009
1010
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1008

def selective_gapic_generation
  @selective_gapic_generation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1015
1016
1017
1018
1019
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1015

def update!(**args)
  @destinations = args[:destinations] if args.key?(:destinations)
  @reference_docs_uri = args[:reference_docs_uri] if args.key?(:reference_docs_uri)
  @selective_gapic_generation = args[:selective_gapic_generation] if args.key?(:selective_gapic_generation)
end