Class: Google::Apis::ServicenetworkingV1beta::Connection
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1beta::Connection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb
Overview
Represents a private connection resource. A private connection is implemented as a VPC Network Peering connection between a service producer's VPC network and a service consumer's VPC network.
Instance Attribute Summary collapse
-
#network ⇒ String
Required.
-
#peering ⇒ String
Output only.
-
#reserved_peering_ranges ⇒ Array<String>
The name of one or more allocated IP address ranges for this service producer of type
PEERING. -
#service ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Connection
constructor
A new instance of Connection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Connection
Returns a new instance of Connection.
1060 1061 1062 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1060 def initialize(**args) update!(**args) end |
Instance Attribute Details
#network ⇒ String
Required. The name of service consumer's VPC network that's connected with
service producer network, in the following format: projects/project/global/
networks/network.projectis a project number, such as in `12345` that
includes the VPC service consumer's VPC network.network`is the name of
the service consumer's VPC network.
Corresponds to the JSON propertynetwork`
1035 1036 1037 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1035 def network @network end |
#peering ⇒ String
Output only. The name of the VPC Network Peering connection that was created
by the service producer.
Corresponds to the JSON property peering
1041 1042 1043 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1041 def peering @peering end |
#reserved_peering_ranges ⇒ Array<String>
The name of one or more allocated IP address ranges for this service producer
of type PEERING. Note that invoking CreateConnection method with a different
range when connection is already established will not modify already
provisioned service producer subnetworks. If CreateConnection method is
invoked repeatedly to reconnect when peering connection had been disconnected
on the consumer side, leaving this field empty will restore previously
allocated IP ranges.
Corresponds to the JSON property reservedPeeringRanges
1052 1053 1054 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1052 def reserved_peering_ranges @reserved_peering_ranges end |
#service ⇒ String
Output only. The name of the peering service that's associated with this
connection, in the following format: services/service name`.
Corresponds to the JSON propertyservice`
1058 1059 1060 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1058 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1065 1066 1067 1068 1069 1070 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1065 def update!(**args) @network = args[:network] if args.key?(:network) @peering = args[:peering] if args.key?(:peering) @reserved_peering_ranges = args[:reserved_peering_ranges] if args.key?(:reserved_peering_ranges) @service = args[:service] if args.key?(:service) end |