Class: Google::Apis::ServicenetworkingV1beta::Context

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

Context defines which contexts an API requests. Example: context: rules: - selector: "*" requested: - google.rpc.context.ProjectContext - google.rpc. context.OriginContext The above specifies that all methods in the API request google.rpc.context.ProjectContext and google.rpc.context.OriginContext. Available context types are defined in package google.rpc.context. This also provides mechanism to allowlist any protobuf message extension that can be sent in grpc metadata using “x-goog-ext--bin” and “x-goog-ext--jspb” format. For example, list any service specific protobuf types that can appear in grpc metadata as follows in your yaml file: Example: context: rules: - selector: " google.example.library.v1.LibraryService.CreateBook" allowed_request_extensions: - google.foo.v1.NewExtension allowed_response_extensions: - google.foo.v1.NewExtension You can also specify extension ID instead of fully qualified extension name here.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Context

Returns a new instance of Context.



1184
1185
1186
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1184

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rulesArray<Google::Apis::ServicenetworkingV1beta::ContextRule>

A list of RPC context rules that apply to individual API methods. NOTE: All service configuration rules follow "last one wins" order. Corresponds to the JSON property rules



1182
1183
1184
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1182

def rules
  @rules
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1189
1190
1191
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1189

def update!(**args)
  @rules = args[:rules] if args.key?(:rules)
end