Class: Google::Apis::ServicenetworkingV1beta::DotnetSettings
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1beta::DotnetSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb
Overview
Settings for Dotnet client libraries.
Instance Attribute Summary collapse
-
#common ⇒ Google::Apis::ServicenetworkingV1beta::CommonLanguageSettings
Required information for every language.
-
#forced_namespace_aliases ⇒ Array<String>
Namespaces which must be aliased in snippets due to a known (but non-generator- predictable) naming collision Corresponds to the JSON property
forcedNamespaceAliases. -
#handwritten_signatures ⇒ Array<String>
Method signatures (in the form "service.method(signature)") which are provided separately, so shouldn't be generated.
-
#ignored_resources ⇒ Array<String>
List of full resource types to ignore during generation.
-
#renamed_resources ⇒ Hash<String,String>
Map from full resource types to the effective short name for the resource.
-
#renamed_services ⇒ Hash<String,String>
Map from original service names to renamed versions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DotnetSettings
constructor
A new instance of DotnetSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DotnetSettings
Returns a new instance of DotnetSettings.
1657 1658 1659 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1657 def initialize(**args) update!(**args) end |
Instance Attribute Details
#common ⇒ Google::Apis::ServicenetworkingV1beta::CommonLanguageSettings
Required information for every language.
Corresponds to the JSON property common
1619 1620 1621 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1619 def common @common end |
#forced_namespace_aliases ⇒ Array<String>
Namespaces which must be aliased in snippets due to a known (but non-generator-
predictable) naming collision
Corresponds to the JSON property forcedNamespaceAliases
1625 1626 1627 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1625 def forced_namespace_aliases @forced_namespace_aliases end |
#handwritten_signatures ⇒ Array<String>
Method signatures (in the form "service.method(signature)") which are provided
separately, so shouldn't be generated. Snippets calling these methods are
still generated, however.
Corresponds to the JSON property handwrittenSignatures
1632 1633 1634 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1632 def handwritten_signatures @handwritten_signatures end |
#ignored_resources ⇒ Array<String>
List of full resource types to ignore during generation. This is typically
used for API-specific Location resources, which should be handled by the
generator as if they were actually the common Location resources. Example
entry: "documentai.googleapis.com/Location"
Corresponds to the JSON property ignoredResources
1640 1641 1642 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1640 def ignored_resources @ignored_resources end |
#renamed_resources ⇒ Hash<String,String>
Map from full resource types to the effective short name for the resource.
This is used when otherwise resource named from different services would cause
naming collisions. Example entry: "datalabeling.googleapis.com/Dataset": "
DataLabelingDataset"
Corresponds to the JSON property renamedResources
1648 1649 1650 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1648 def renamed_resources @renamed_resources end |
#renamed_services ⇒ Hash<String,String>
Map from original service names to renamed versions. This is used when the
default generated types would cause a naming conflict. (Neither name is fully-
qualified.) Example: Subscriber to SubscriberServiceApi.
Corresponds to the JSON property renamedServices
1655 1656 1657 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1655 def renamed_services @renamed_services end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1662 1663 1664 1665 1666 1667 1668 1669 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1662 def update!(**args) @common = args[:common] if args.key?(:common) @forced_namespace_aliases = args[:forced_namespace_aliases] if args.key?(:forced_namespace_aliases) @handwritten_signatures = args[:handwritten_signatures] if args.key?(:handwritten_signatures) @ignored_resources = args[:ignored_resources] if args.key?(:ignored_resources) @renamed_resources = args[:renamed_resources] if args.key?(:renamed_resources) @renamed_services = args[:renamed_services] if args.key?(:renamed_services) end |