Class: Google::Apis::ServicenetworkingV1beta::Field

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

A single field of a message type. New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Field

Returns a new instance of Field.



1966
1967
1968
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1966

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cardinalityString

The field cardinality. Corresponds to the JSON property cardinality

Returns:

  • (String)


1916
1917
1918
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1916

def cardinality
  @cardinality
end

#default_valueString

The string value of the default value of this field. Proto2 syntax only. Corresponds to the JSON property defaultValue

Returns:

  • (String)


1921
1922
1923
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1921

def default_value
  @default_value
end

#json_nameString

The field JSON name. Corresponds to the JSON property jsonName

Returns:

  • (String)


1926
1927
1928
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1926

def json_name
  @json_name
end

#kindString

The field type. Corresponds to the JSON property kind

Returns:

  • (String)


1931
1932
1933
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1931

def kind
  @kind
end

#nameString

The field name. Corresponds to the JSON property name

Returns:

  • (String)


1936
1937
1938
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1936

def name
  @name
end

#numberFixnum

The field number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


1941
1942
1943
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1941

def number
  @number
end

#oneof_indexFixnum

The index of the field type in Type.oneofs, for message or enumeration types. The first type has index 1; zero means the type is not in the list. Corresponds to the JSON property oneofIndex

Returns:

  • (Fixnum)


1947
1948
1949
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1947

def oneof_index
  @oneof_index
end

#optionsArray<Google::Apis::ServicenetworkingV1beta::Option>

The protocol buffer options. Corresponds to the JSON property options



1952
1953
1954
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1952

def options
  @options
end

#packedBoolean Also known as: packed?

Whether to use alternative packed wire representation. Corresponds to the JSON property packed

Returns:

  • (Boolean)


1957
1958
1959
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1957

def packed
  @packed
end

#type_urlString

The field type URL, without the scheme, for message or enumeration types. Example: "type.googleapis.com/google.protobuf.Timestamp". Corresponds to the JSON property typeUrl

Returns:

  • (String)


1964
1965
1966
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1964

def type_url
  @type_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1971

def update!(**args)
  @cardinality = args[:cardinality] if args.key?(:cardinality)
  @default_value = args[:default_value] if args.key?(:default_value)
  @json_name = args[:json_name] if args.key?(:json_name)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @oneof_index = args[:oneof_index] if args.key?(:oneof_index)
  @options = args[:options] if args.key?(:options)
  @packed = args[:packed] if args.key?(:packed)
  @type_url = args[:type_url] if args.key?(:type_url)
end