Class: Google::Apis::ServicenetworkingV1beta::FieldPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

Google API Policy Annotation This message defines a simple API policy annotation that can be used to annotate API request and response message fields with applicable policies. One field may have multiple applicable policies that must all be satisfied before a request can be processed. This policy annotation is used to generate the overall policy that will be used for automatic runtime policy enforcement and documentation generation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FieldPolicy

Returns a new instance of FieldPolicy.



2017
2018
2019
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2017

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_permissionString

Specifies the required permission(s) for the resource referred to by the field. It requires the field contains a valid resource reference, and the request must pass the permission checks to proceed. For example, "resourcemanager. projects.get". Corresponds to the JSON property resourcePermission

Returns:

  • (String)


2000
2001
2002
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2000

def resource_permission
  @resource_permission
end

#resource_typeString

Specifies the resource type for the resource referred to by the field. Corresponds to the JSON property resourceType

Returns:

  • (String)


2005
2006
2007
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2005

def resource_type
  @resource_type
end

#selectorString

Selects one or more request or response message fields to apply this FieldPolicy. When a FieldPolicy is used in proto annotation, the selector must be left as empty. The service config generator will automatically fill the correct value. When a FieldPolicy is used in service config, the selector must be a comma-separated string with valid request or response field paths, such as "foo.bar" or "foo.bar,foo.baz". Corresponds to the JSON property selector

Returns:

  • (String)


2015
2016
2017
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2015

def selector
  @selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2022
2023
2024
2025
2026
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2022

def update!(**args)
  @resource_permission = args[:resource_permission] if args.key?(:resource_permission)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @selector = args[:selector] if args.key?(:selector)
end