Class: Google::Apis::ServicenetworkingV1beta::MethodProp
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1beta::MethodProp
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb
Overview
Method represents a method of an API interface. New usages of this message as an alternative to MethodDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#name ⇒ String
The simple name of this method.
-
#options ⇒ Array<Google::Apis::ServicenetworkingV1beta::Option>
Any metadata attached to the method.
-
#request_streaming ⇒ Boolean
(also: #request_streaming?)
If true, the request is streamed.
-
#request_type_url ⇒ String
A URL of the input message type.
-
#response_streaming ⇒ Boolean
(also: #response_streaming?)
If true, the response is streamed.
-
#response_type_url ⇒ String
The URL of the output message type.
-
#syntax ⇒ String
The source syntax of this method.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MethodProp
constructor
A new instance of MethodProp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MethodProp
Returns a new instance of MethodProp.
2765 2766 2767 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2765 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS. This
field should be ignored, instead the edition should be inherited from Api.
This is similar to Field and EnumValue.
Corresponds to the JSON property edition
2725 2726 2727 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2725 def edition @edition end |
#name ⇒ String
The simple name of this method.
Corresponds to the JSON property name
2730 2731 2732 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2730 def name @name end |
#options ⇒ Array<Google::Apis::ServicenetworkingV1beta::Option>
Any metadata attached to the method.
Corresponds to the JSON property options
2735 2736 2737 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2735 def @options end |
#request_streaming ⇒ Boolean Also known as: request_streaming?
If true, the request is streamed.
Corresponds to the JSON property requestStreaming
2740 2741 2742 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2740 def request_streaming @request_streaming end |
#request_type_url ⇒ String
A URL of the input message type.
Corresponds to the JSON property requestTypeUrl
2746 2747 2748 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2746 def request_type_url @request_type_url end |
#response_streaming ⇒ Boolean Also known as: response_streaming?
If true, the response is streamed.
Corresponds to the JSON property responseStreaming
2751 2752 2753 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2751 def response_streaming @response_streaming end |
#response_type_url ⇒ String
The URL of the output message type.
Corresponds to the JSON property responseTypeUrl
2757 2758 2759 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2757 def response_type_url @response_type_url end |
#syntax ⇒ String
The source syntax of this method. This field should be ignored, instead the
syntax should be inherited from Api. This is similar to Field and EnumValue.
Corresponds to the JSON property syntax
2763 2764 2765 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2763 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2770 2771 2772 2773 2774 2775 2776 2777 2778 2779 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2770 def update!(**args) @edition = args[:edition] if args.key?(:edition) @name = args[:name] if args.key?(:name) @options = args[:options] if args.key?(:options) @request_streaming = args[:request_streaming] if args.key?(:request_streaming) @request_type_url = args[:request_type_url] if args.key?(:request_type_url) @response_streaming = args[:response_streaming] if args.key?(:response_streaming) @response_type_url = args[:response_type_url] if args.key?(:response_type_url) @syntax = args[:syntax] if args.key?(:syntax) end |