Class: Google::Apis::ServicenetworkingV1beta::MetricRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

Bind API methods to metrics. Binding a method to a metric causes that metric's configured quota behaviors to apply to the method call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetricRule

Returns a new instance of MetricRule.



3080
3081
3082
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3080

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agentic_metric_costsHash<String,Fixnum>

Optional. Metrics to update when the selected methods are called, and the associated cost applied to each metric, iff the source of the call is an agent. The key of the map is the metric name, and the values are the amount increased for the metric against which the quota limits are defined. The value must not be negative. Corresponds to the JSON property agenticMetricCosts

Returns:

  • (Hash<String,Fixnum>)


3055
3056
3057
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3055

def agentic_metric_costs
  @agentic_metric_costs
end

#metric_costsHash<String,Fixnum>

Metrics to update when the selected methods are called, and the associated cost applied to each metric. The key of the map is the metric name, and the values are the amount increased for the metric against which the quota limits are defined. The value must not be negative. Corresponds to the JSON property metricCosts

Returns:

  • (Hash<String,Fixnum>)


3063
3064
3065
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3063

def metric_costs
  @metric_costs
end

#nonagentic_metric_costsHash<String,Fixnum>

Optional. Metrics to update when the selected methods are called, and the associated cost applied to each metric, iff the source of the call is not an agent. The key of the map is the metric name, and the values are the amount increased for the metric against which the quota limits are defined. The value must not be negative. Corresponds to the JSON property nonagenticMetricCosts

Returns:

  • (Hash<String,Fixnum>)


3072
3073
3074
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3072

def nonagentic_metric_costs
  @nonagentic_metric_costs
end

#selectorString

Selects the methods to which this rule applies. Refer to selector for syntax details. Corresponds to the JSON property selector

Returns:

  • (String)


3078
3079
3080
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3078

def selector
  @selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3085
3086
3087
3088
3089
3090
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3085

def update!(**args)
  @agentic_metric_costs = args[:agentic_metric_costs] if args.key?(:agentic_metric_costs)
  @metric_costs = args[:metric_costs] if args.key?(:metric_costs)
  @nonagentic_metric_costs = args[:nonagentic_metric_costs] if args.key?(:nonagentic_metric_costs)
  @selector = args[:selector] if args.key?(:selector)
end