Class: Google::Apis::ServicenetworkingV1beta::Publishing

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

This message configures the settings for publishing Google Cloud Client libraries generated from the service config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Publishing

Returns a new instance of Publishing.



3664
3665
3666
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3664

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_short_nameString

Used as a tracking tag when collecting data about the APIs developer relations artifacts like docs, packages delivered to package managers, etc. Example: " speech". Corresponds to the JSON property apiShortName

Returns:

  • (String)


3603
3604
3605
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3603

def api_short_name
  @api_short_name
end

#codeowner_github_teamsArray<String>

GitHub teams to be added to CODEOWNERS in the directory in GitHub containing source code for the client libraries for this API. Corresponds to the JSON property codeownerGithubTeams

Returns:

  • (Array<String>)


3609
3610
3611
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3609

def codeowner_github_teams
  @codeowner_github_teams
end

#doc_tag_prefixString

A prefix used in sample code when demarking regions to be included in documentation. Corresponds to the JSON property docTagPrefix

Returns:

  • (String)


3615
3616
3617
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3615

def doc_tag_prefix
  @doc_tag_prefix
end

#documentation_uriString

Link to product home page. Example: https://cloud.google.com/asset-inventory/ docs/overview Corresponds to the JSON property documentationUri

Returns:

  • (String)


3621
3622
3623
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3621

def documentation_uri
  @documentation_uri
end

#github_labelString

GitHub label to apply to issues and pull requests opened for this API. Corresponds to the JSON property githubLabel

Returns:

  • (String)


3626
3627
3628
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3626

def github_label
  @github_label
end

#library_settingsArray<Google::Apis::ServicenetworkingV1beta::ClientLibrarySettings>

Client library settings. If the same version string appears multiple times in this list, then the last one wins. Settings from earlier settings with the same version string are discarded. Corresponds to the JSON property librarySettings



3633
3634
3635
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3633

def library_settings
  @library_settings
end

#method_settingsArray<Google::Apis::ServicenetworkingV1beta::MethodSettings>

A list of API method settings, e.g. the behavior for methods that use the long- running operation pattern. Corresponds to the JSON property methodSettings



3639
3640
3641
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3639

def method_settings
  @method_settings
end

#new_issue_uriString

Link to a public URI where users can report issues. Example: https:// issuetracker.google.com/issues/new?component=190865&template=1161103 Corresponds to the JSON property newIssueUri

Returns:

  • (String)


3645
3646
3647
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3645

def new_issue_uri
  @new_issue_uri
end

#organizationString

For whom the client library is being published. Corresponds to the JSON property organization

Returns:

  • (String)


3650
3651
3652
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3650

def organization
  @organization
end

#proto_reference_documentation_uriString

Optional link to proto reference documentation. Example: https://cloud.google. com/pubsub/lite/docs/reference/rpc Corresponds to the JSON property protoReferenceDocumentationUri

Returns:

  • (String)


3656
3657
3658
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3656

def proto_reference_documentation_uri
  @proto_reference_documentation_uri
end

#rest_reference_documentation_uriString

Optional link to REST reference documentation. Example: https://cloud.google. com/pubsub/lite/docs/reference/rest Corresponds to the JSON property restReferenceDocumentationUri

Returns:

  • (String)


3662
3663
3664
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3662

def rest_reference_documentation_uri
  @rest_reference_documentation_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3669
3670
3671
3672
3673
3674
3675
3676
3677
3678
3679
3680
3681
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3669

def update!(**args)
  @api_short_name = args[:api_short_name] if args.key?(:api_short_name)
  @codeowner_github_teams = args[:codeowner_github_teams] if args.key?(:codeowner_github_teams)
  @doc_tag_prefix = args[:doc_tag_prefix] if args.key?(:doc_tag_prefix)
  @documentation_uri = args[:documentation_uri] if args.key?(:documentation_uri)
  @github_label = args[:github_label] if args.key?(:github_label)
  @library_settings = args[:library_settings] if args.key?(:library_settings)
  @method_settings = args[:method_settings] if args.key?(:method_settings)
  @new_issue_uri = args[:new_issue_uri] if args.key?(:new_issue_uri)
  @organization = args[:organization] if args.key?(:organization)
  @proto_reference_documentation_uri = args[:proto_reference_documentation_uri] if args.key?(:proto_reference_documentation_uri)
  @rest_reference_documentation_uri = args[:rest_reference_documentation_uri] if args.key?(:rest_reference_documentation_uri)
end