Class: Google::Apis::ServicenetworkingV1beta::SelectiveGapicGeneration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

This message is used to configure the generation of a subset of the RPCs in a service for client libraries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SelectiveGapicGeneration

Returns a new instance of SelectiveGapicGeneration.



4038
4039
4040
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4038

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#generate_omitted_as_internalBoolean Also known as: generate_omitted_as_internal?

Setting this to true indicates to the client generators that methods that would be excluded from the generation should instead be generated in a way that indicates these methods should not be consumed by end users. How this is expressed is up to individual language implementations to decide. Some examples may be: added annotations, obfuscated identifiers, or other language idiomatic patterns. Corresponds to the JSON property generateOmittedAsInternal

Returns:

  • (Boolean)


4029
4030
4031
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4029

def generate_omitted_as_internal
  @generate_omitted_as_internal
end

#methods_propArray<String>

An allowlist of the fully qualified names of RPCs that should be included on public client surfaces. Corresponds to the JSON property methods

Returns:

  • (Array<String>)


4036
4037
4038
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4036

def methods_prop
  @methods_prop
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4043
4044
4045
4046
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4043

def update!(**args)
  @generate_omitted_as_internal = args[:generate_omitted_as_internal] if args.key?(:generate_omitted_as_internal)
  @methods_prop = args[:methods_prop] if args.key?(:methods_prop)
end