Class: Google::Apis::ServicenetworkingV1beta::Subnetwork

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

Represents a subnet that was created or discovered by a private access management service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Subnetwork

Returns a new instance of Subnetwork.



4553
4554
4555
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4553

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_cidr_rangeString

Subnetwork CIDR range in 10.x.x.x/y format. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


4523
4524
4525
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4523

def ip_cidr_range
  @ip_cidr_range
end

#nameString

Subnetwork name. See https://cloud.google.com/compute/docs/vpc/ Corresponds to the JSON property name

Returns:

  • (String)


4528
4529
4530
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4528

def name
  @name
end

#networkString

In the Shared VPC host project, the VPC network that's peered with the consumer network. For example: projects/1234321/global/networks/host-network Corresponds to the JSON property network

Returns:

  • (String)


4534
4535
4536
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4534

def network
  @network
end

#outside_allocationBoolean Also known as: outside_allocation?

This is a discovered subnet that is not within the current consumer allocated ranges. Corresponds to the JSON property outsideAllocation

Returns:

  • (Boolean)


4540
4541
4542
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4540

def outside_allocation
  @outside_allocation
end

#regionString

GCP region where the subnetwork is located. Corresponds to the JSON property region

Returns:

  • (String)


4546
4547
4548
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4546

def region
  @region
end

#secondary_ip_rangesArray<Google::Apis::ServicenetworkingV1beta::SecondaryIpRange>

List of secondary IP ranges in this subnetwork. Corresponds to the JSON property secondaryIpRanges



4551
4552
4553
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4551

def secondary_ip_ranges
  @secondary_ip_ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4558
4559
4560
4561
4562
4563
4564
4565
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4558

def update!(**args)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @outside_allocation = args[:outside_allocation] if args.key?(:outside_allocation)
  @region = args[:region] if args.key?(:region)
  @secondary_ip_ranges = args[:secondary_ip_ranges] if args.key?(:secondary_ip_ranges)
end