Class: Google::Apis::ServicenetworkingV1beta::ConsumerConfig
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1beta::ConsumerConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb
Overview
Configuration information for a private service access connection.
Instance Attribute Summary collapse
-
#cloudsql_configs ⇒ Array<Google::Apis::ServicenetworkingV1beta::CloudSqlConfig>
Represents one or multiple Cloud SQL configurations.
-
#consumer_export_custom_routes ⇒ Boolean
(also: #consumer_export_custom_routes?)
Export custom routes flag value for peering from consumer to producer.
-
#consumer_export_subnet_routes_with_public_ip ⇒ Boolean
(also: #consumer_export_subnet_routes_with_public_ip?)
Export subnet routes with public ip flag value for peering from consumer to producer.
-
#consumer_import_custom_routes ⇒ Boolean
(also: #consumer_import_custom_routes?)
Import custom routes flag value for peering from consumer to producer.
-
#consumer_import_subnet_routes_with_public_ip ⇒ Boolean
(also: #consumer_import_subnet_routes_with_public_ip?)
Import subnet routes with public ip flag value for peering from consumer to producer.
-
#consumer_peering_active ⇒ Boolean
(also: #consumer_peering_active?)
Output only.
-
#producer_export_custom_routes ⇒ Boolean
(also: #producer_export_custom_routes?)
Export custom routes flag value for peering from producer to consumer.
-
#producer_export_subnet_routes_with_public_ip ⇒ Boolean
(also: #producer_export_subnet_routes_with_public_ip?)
Export subnet routes with public ip flag value for peering from producer to consumer.
-
#producer_import_custom_routes ⇒ Boolean
(also: #producer_import_custom_routes?)
Import custom routes flag value for peering from producer to consumer.
-
#producer_import_subnet_routes_with_public_ip ⇒ Boolean
(also: #producer_import_subnet_routes_with_public_ip?)
Import subnet routes with public ip flag value for peering from producer to consumer.
-
#producer_network ⇒ String
Output only.
-
#reserved_ranges ⇒ Array<Google::Apis::ServicenetworkingV1beta::GoogleCloudServicenetworkingV1ConsumerConfigReservedRange>
Output only.
-
#used_ip_ranges ⇒ Array<String>
Output only.
-
#vpc_sc_reference_architecture_enabled ⇒ Boolean
(also: #vpc_sc_reference_architecture_enabled?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsumerConfig
constructor
A new instance of ConsumerConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsumerConfig
Returns a new instance of ConsumerConfig.
1168 1169 1170 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1168 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloudsql_configs ⇒ Array<Google::Apis::ServicenetworkingV1beta::CloudSqlConfig>
Represents one or multiple Cloud SQL configurations.
Corresponds to the JSON property cloudsqlConfigs
1083 1084 1085 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1083 def cloudsql_configs @cloudsql_configs end |
#consumer_export_custom_routes ⇒ Boolean Also known as: consumer_export_custom_routes?
Export custom routes flag value for peering from consumer to producer.
Corresponds to the JSON property consumerExportCustomRoutes
1088 1089 1090 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1088 def consumer_export_custom_routes @consumer_export_custom_routes end |
#consumer_export_subnet_routes_with_public_ip ⇒ Boolean Also known as: consumer_export_subnet_routes_with_public_ip?
Export subnet routes with public ip flag value for peering from consumer to
producer.
Corresponds to the JSON property consumerExportSubnetRoutesWithPublicIp
1095 1096 1097 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1095 def consumer_export_subnet_routes_with_public_ip @consumer_export_subnet_routes_with_public_ip end |
#consumer_import_custom_routes ⇒ Boolean Also known as: consumer_import_custom_routes?
Import custom routes flag value for peering from consumer to producer.
Corresponds to the JSON property consumerImportCustomRoutes
1101 1102 1103 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1101 def consumer_import_custom_routes @consumer_import_custom_routes end |
#consumer_import_subnet_routes_with_public_ip ⇒ Boolean Also known as: consumer_import_subnet_routes_with_public_ip?
Import subnet routes with public ip flag value for peering from consumer to
producer.
Corresponds to the JSON property consumerImportSubnetRoutesWithPublicIp
1108 1109 1110 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1108 def consumer_import_subnet_routes_with_public_ip @consumer_import_subnet_routes_with_public_ip end |
#consumer_peering_active ⇒ Boolean Also known as: consumer_peering_active?
Output only. If this is true, consumer peering is active.
Corresponds to the JSON property consumerPeeringActive
1114 1115 1116 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1114 def consumer_peering_active @consumer_peering_active end |
#producer_export_custom_routes ⇒ Boolean Also known as: producer_export_custom_routes?
Export custom routes flag value for peering from producer to consumer.
Corresponds to the JSON property producerExportCustomRoutes
1120 1121 1122 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1120 def producer_export_custom_routes @producer_export_custom_routes end |
#producer_export_subnet_routes_with_public_ip ⇒ Boolean Also known as: producer_export_subnet_routes_with_public_ip?
Export subnet routes with public ip flag value for peering from producer to
consumer.
Corresponds to the JSON property producerExportSubnetRoutesWithPublicIp
1127 1128 1129 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1127 def producer_export_subnet_routes_with_public_ip @producer_export_subnet_routes_with_public_ip end |
#producer_import_custom_routes ⇒ Boolean Also known as: producer_import_custom_routes?
Import custom routes flag value for peering from producer to consumer.
Corresponds to the JSON property producerImportCustomRoutes
1133 1134 1135 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1133 def producer_import_custom_routes @producer_import_custom_routes end |
#producer_import_subnet_routes_with_public_ip ⇒ Boolean Also known as: producer_import_subnet_routes_with_public_ip?
Import subnet routes with public ip flag value for peering from producer to
consumer.
Corresponds to the JSON property producerImportSubnetRoutesWithPublicIp
1140 1141 1142 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1140 def producer_import_subnet_routes_with_public_ip @producer_import_subnet_routes_with_public_ip end |
#producer_network ⇒ String
Output only. The VPC host network that is used to host managed service
instances. In the format, projects/project/global/networks/network where
project is the project number e.g. '12345' and network is the network name.
Corresponds to the JSON property producerNetwork
1148 1149 1150 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1148 def producer_network @producer_network end |
#reserved_ranges ⇒ Array<Google::Apis::ServicenetworkingV1beta::GoogleCloudServicenetworkingV1ConsumerConfigReservedRange>
Output only. The reserved ranges associated with this private service access
connection.
Corresponds to the JSON property reservedRanges
1154 1155 1156 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1154 def reserved_ranges @reserved_ranges end |
#used_ip_ranges ⇒ Array<String>
Output only. The IP ranges already in use by consumer or producer
Corresponds to the JSON property usedIpRanges
1159 1160 1161 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1159 def used_ip_ranges @used_ip_ranges end |
#vpc_sc_reference_architecture_enabled ⇒ Boolean Also known as: vpc_sc_reference_architecture_enabled?
Output only. Indicates whether the VPC Service Controls reference architecture
is configured for the producer VPC host network.
Corresponds to the JSON property vpcScReferenceArchitectureEnabled
1165 1166 1167 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1165 def vpc_sc_reference_architecture_enabled @vpc_sc_reference_architecture_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1173 def update!(**args) @cloudsql_configs = args[:cloudsql_configs] if args.key?(:cloudsql_configs) @consumer_export_custom_routes = args[:consumer_export_custom_routes] if args.key?(:consumer_export_custom_routes) @consumer_export_subnet_routes_with_public_ip = args[:consumer_export_subnet_routes_with_public_ip] if args.key?(:consumer_export_subnet_routes_with_public_ip) @consumer_import_custom_routes = args[:consumer_import_custom_routes] if args.key?(:consumer_import_custom_routes) @consumer_import_subnet_routes_with_public_ip = args[:consumer_import_subnet_routes_with_public_ip] if args.key?(:consumer_import_subnet_routes_with_public_ip) @consumer_peering_active = args[:consumer_peering_active] if args.key?(:consumer_peering_active) @producer_export_custom_routes = args[:producer_export_custom_routes] if args.key?(:producer_export_custom_routes) @producer_export_subnet_routes_with_public_ip = args[:producer_export_subnet_routes_with_public_ip] if args.key?(:producer_export_subnet_routes_with_public_ip) @producer_import_custom_routes = args[:producer_import_custom_routes] if args.key?(:producer_import_custom_routes) @producer_import_subnet_routes_with_public_ip = args[:producer_import_subnet_routes_with_public_ip] if args.key?(:producer_import_subnet_routes_with_public_ip) @producer_network = args[:producer_network] if args.key?(:producer_network) @reserved_ranges = args[:reserved_ranges] if args.key?(:reserved_ranges) @used_ip_ranges = args[:used_ip_ranges] if args.key?(:used_ip_ranges) @vpc_sc_reference_architecture_enabled = args[:vpc_sc_reference_architecture_enabled] if args.key?(:vpc_sc_reference_architecture_enabled) end |