Class: Google::Apis::ServicenetworkingV1beta::CustomErrorRule
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1beta::CustomErrorRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb
Overview
A custom error rule.
Instance Attribute Summary collapse
-
#is_error_type ⇒ Boolean
(also: #is_error_type?)
Mark this message as possible payload in error response.
-
#selector ⇒ String
Selects messages to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomErrorRule
constructor
A new instance of CustomErrorRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomErrorRule
Returns a new instance of CustomErrorRule.
1336 1337 1338 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1336 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_error_type ⇒ Boolean Also known as: is_error_type?
Mark this message as possible payload in error response. Otherwise, objects of
this type will be filtered when they appear in error payload.
Corresponds to the JSON property isErrorType
1327 1328 1329 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1327 def is_error_type @is_error_type end |
#selector ⇒ String
Selects messages to which this rule applies. Refer to selector for syntax
details.
Corresponds to the JSON property selector
1334 1335 1336 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1334 def selector @selector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1341 1342 1343 1344 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1341 def update!(**args) @is_error_type = args[:is_error_type] if args.key?(:is_error_type) @selector = args[:selector] if args.key?(:selector) end |