Class: Google::Apis::ServicenetworkingV1beta::Enum
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1beta::Enum
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb
Overview
Enum type definition. New usages of this message as an alternative to EnumDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#enumvalue ⇒ Array<Google::Apis::ServicenetworkingV1beta::EnumValue>
Enum value definitions.
-
#name ⇒ String
Enum type name.
-
#options ⇒ Array<Google::Apis::ServicenetworkingV1beta::Option>
Protocol buffer options.
-
#source_context ⇒ Google::Apis::ServicenetworkingV1beta::SourceContext
SourceContextrepresents information about the source of a protobuf element, like the file in which it is defined. -
#syntax ⇒ String
The source syntax.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Enum
constructor
A new instance of Enum.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Enum
Returns a new instance of Enum.
1769 1770 1771 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1769 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
Corresponds to the JSON property edition
1741 1742 1743 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1741 def edition @edition end |
#enumvalue ⇒ Array<Google::Apis::ServicenetworkingV1beta::EnumValue>
Enum value definitions.
Corresponds to the JSON property enumvalue
1746 1747 1748 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1746 def enumvalue @enumvalue end |
#name ⇒ String
Enum type name.
Corresponds to the JSON property name
1751 1752 1753 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1751 def name @name end |
#options ⇒ Array<Google::Apis::ServicenetworkingV1beta::Option>
Protocol buffer options.
Corresponds to the JSON property options
1756 1757 1758 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1756 def @options end |
#source_context ⇒ Google::Apis::ServicenetworkingV1beta::SourceContext
SourceContext represents information about the source of a protobuf element,
like the file in which it is defined.
Corresponds to the JSON property sourceContext
1762 1763 1764 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1762 def source_context @source_context end |
#syntax ⇒ String
The source syntax.
Corresponds to the JSON property syntax
1767 1768 1769 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1767 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1774 1775 1776 1777 1778 1779 1780 1781 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1774 def update!(**args) @edition = args[:edition] if args.key?(:edition) @enumvalue = args[:enumvalue] if args.key?(:enumvalue) @name = args[:name] if args.key?(:name) @options = args[:options] if args.key?(:options) @source_context = args[:source_context] if args.key?(:source_context) @syntax = args[:syntax] if args.key?(:syntax) end |