Class: Google::Apis::ServicenetworkingV1beta::EnumValue
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1beta::EnumValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb
Overview
Enum value definition. New usages of this message as an alternative to EnumValueDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#name ⇒ String
Enum value name.
-
#number ⇒ Fixnum
Enum value number.
-
#options ⇒ Array<Google::Apis::ServicenetworkingV1beta::Option>
Protocol buffer options.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EnumValue
constructor
A new instance of EnumValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EnumValue
Returns a new instance of EnumValue.
1850 1851 1852 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1850 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Enum value name.
Corresponds to the JSON property name
1838 1839 1840 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1838 def name @name end |
#number ⇒ Fixnum
Enum value number.
Corresponds to the JSON property number
1843 1844 1845 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1843 def number @number end |
#options ⇒ Array<Google::Apis::ServicenetworkingV1beta::Option>
Protocol buffer options.
Corresponds to the JSON property options
1848 1849 1850 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1848 def @options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1855 1856 1857 1858 1859 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1855 def update!(**args) @name = args[:name] if args.key?(:name) @number = args[:number] if args.key?(:number) @options = args[:options] if args.key?(:options) end |