Class: Google::Apis::ServicenetworkingV1beta::EnumValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

Enum value definition. New usages of this message as an alternative to EnumValueDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EnumValue

Returns a new instance of EnumValue.



1840
1841
1842
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1840

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Enum value name. Corresponds to the JSON property name

Returns:

  • (String)


1828
1829
1830
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1828

def name
  @name
end

#numberFixnum

Enum value number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


1833
1834
1835
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1833

def number
  @number
end

#optionsArray<Google::Apis::ServicenetworkingV1beta::Option>

Protocol buffer options. Corresponds to the JSON property options



1838
1839
1840
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1838

def options
  @options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1845
1846
1847
1848
1849
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1845

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @options = args[:options] if args.key?(:options)
end