Class: Google::Apis::ServicenetworkingV1beta::EnumValue
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1beta::EnumValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb
Overview
Enum value definition. New usages of this message as an alternative to EnumValueDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#name ⇒ String
Enum value name.
-
#number ⇒ Fixnum
Enum value number.
-
#options ⇒ Array<Google::Apis::ServicenetworkingV1beta::Option>
Protocol buffer options.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EnumValue
constructor
A new instance of EnumValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EnumValue
Returns a new instance of EnumValue.
1807 1808 1809 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1807 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Enum value name.
Corresponds to the JSON property name
1795 1796 1797 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1795 def name @name end |
#number ⇒ Fixnum
Enum value number.
Corresponds to the JSON property number
1800 1801 1802 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1800 def number @number end |
#options ⇒ Array<Google::Apis::ServicenetworkingV1beta::Option>
Protocol buffer options.
Corresponds to the JSON property options
1805 1806 1807 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1805 def @options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1812 1813 1814 1815 1816 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1812 def update!(**args) @name = args[:name] if args.key?(:name) @number = args[:number] if args.key?(:number) @options = args[:options] if args.key?(:options) end |