Class: Google::Apis::ServicenetworkingV1beta::Field

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

A single field of a message type. New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Field

Returns a new instance of Field.



1923
1924
1925
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1923

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cardinalityString

The field cardinality. Corresponds to the JSON property cardinality

Returns:

  • (String)


1873
1874
1875
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1873

def cardinality
  @cardinality
end

#default_valueString

The string value of the default value of this field. Proto2 syntax only. Corresponds to the JSON property defaultValue

Returns:

  • (String)


1878
1879
1880
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1878

def default_value
  @default_value
end

#json_nameString

The field JSON name. Corresponds to the JSON property jsonName

Returns:

  • (String)


1883
1884
1885
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1883

def json_name
  @json_name
end

#kindString

The field type. Corresponds to the JSON property kind

Returns:

  • (String)


1888
1889
1890
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1888

def kind
  @kind
end

#nameString

The field name. Corresponds to the JSON property name

Returns:

  • (String)


1893
1894
1895
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1893

def name
  @name
end

#numberFixnum

The field number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


1898
1899
1900
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1898

def number
  @number
end

#oneof_indexFixnum

The index of the field type in Type.oneofs, for message or enumeration types. The first type has index 1; zero means the type is not in the list. Corresponds to the JSON property oneofIndex

Returns:

  • (Fixnum)


1904
1905
1906
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1904

def oneof_index
  @oneof_index
end

#optionsArray<Google::Apis::ServicenetworkingV1beta::Option>

The protocol buffer options. Corresponds to the JSON property options



1909
1910
1911
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1909

def options
  @options
end

#packedBoolean Also known as: packed?

Whether to use alternative packed wire representation. Corresponds to the JSON property packed

Returns:

  • (Boolean)


1914
1915
1916
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1914

def packed
  @packed
end

#type_urlString

The field type URL, without the scheme, for message or enumeration types. Example: "type.googleapis.com/google.protobuf.Timestamp". Corresponds to the JSON property typeUrl

Returns:

  • (String)


1921
1922
1923
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1921

def type_url
  @type_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 1928

def update!(**args)
  @cardinality = args[:cardinality] if args.key?(:cardinality)
  @default_value = args[:default_value] if args.key?(:default_value)
  @json_name = args[:json_name] if args.key?(:json_name)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @oneof_index = args[:oneof_index] if args.key?(:oneof_index)
  @options = args[:options] if args.key?(:options)
  @packed = args[:packed] if args.key?(:packed)
  @type_url = args[:type_url] if args.key?(:type_url)
end