Class: Google::Apis::ServicenetworkingV1beta::MethodProp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

Method represents a method of an API interface. New usages of this message as an alternative to MethodDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodProp

Returns a new instance of MethodProp.



2755
2756
2757
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2755

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. This field should be ignored, instead the edition should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property edition

Returns:

  • (String)


2715
2716
2717
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2715

def edition
  @edition
end

#nameString

The simple name of this method. Corresponds to the JSON property name

Returns:

  • (String)


2720
2721
2722
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2720

def name
  @name
end

#optionsArray<Google::Apis::ServicenetworkingV1beta::Option>

Any metadata attached to the method. Corresponds to the JSON property options



2725
2726
2727
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2725

def options
  @options
end

#request_streamingBoolean Also known as: request_streaming?

If true, the request is streamed. Corresponds to the JSON property requestStreaming

Returns:

  • (Boolean)


2730
2731
2732
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2730

def request_streaming
  @request_streaming
end

#request_type_urlString

A URL of the input message type. Corresponds to the JSON property requestTypeUrl

Returns:

  • (String)


2736
2737
2738
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2736

def request_type_url
  @request_type_url
end

#response_streamingBoolean Also known as: response_streaming?

If true, the response is streamed. Corresponds to the JSON property responseStreaming

Returns:

  • (Boolean)


2741
2742
2743
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2741

def response_streaming
  @response_streaming
end

#response_type_urlString

The URL of the output message type. Corresponds to the JSON property responseTypeUrl

Returns:

  • (String)


2747
2748
2749
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2747

def response_type_url
  @response_type_url
end

#syntaxString

The source syntax of this method. This field should be ignored, instead the syntax should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property syntax

Returns:

  • (String)


2753
2754
2755
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2753

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2760

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @request_streaming = args[:request_streaming] if args.key?(:request_streaming)
  @request_type_url = args[:request_type_url] if args.key?(:request_type_url)
  @response_streaming = args[:response_streaming] if args.key?(:response_streaming)
  @response_type_url = args[:response_type_url] if args.key?(:response_type_url)
  @syntax = args[:syntax] if args.key?(:syntax)
end