Class: Google::Apis::ServicenetworkingV1beta::MethodSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

Describes the generator configuration for a method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodSettings

Returns a new instance of MethodSettings.



2802
2803
2804
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2802

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_populated_fieldsArray<String>

List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info). format. Currently supported format: UUID4. Example of a YAML configuration: publishing: method_settings: - selector: google.example.v1.ExampleService. CreateExample auto_populated_fields: - request_id Corresponds to the JSON property autoPopulatedFields

Returns:

  • (Array<String>)


2778
2779
2780
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2778

def auto_populated_fields
  @auto_populated_fields
end

#batchingGoogle::Apis::ServicenetworkingV1beta::BatchingConfigProto

BatchingConfigProto defines the batching configuration for an API method. Corresponds to the JSON property batching



2783
2784
2785
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2783

def batching
  @batching
end

#long_runningGoogle::Apis::ServicenetworkingV1beta::LongRunning

Describes settings to use when generating API methods that use the long- running operation pattern. All default values below are from those used in the client library generators (e.g. Java). Corresponds to the JSON property longRunning



2792
2793
2794
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2792

def long_running
  @long_running
end

#selectorString

The fully qualified name of the method, for which the options below apply. This is used to find the method to apply the options. Example: publishing: method_settings: - selector: google.storage.control.v2.StorageControl. CreateFolder # method settings for CreateFolder... Corresponds to the JSON property selector

Returns:

  • (String)


2800
2801
2802
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2800

def selector
  @selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2807
2808
2809
2810
2811
2812
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2807

def update!(**args)
  @auto_populated_fields = args[:auto_populated_fields] if args.key?(:auto_populated_fields)
  @batching = args[:batching] if args.key?(:batching)
  @long_running = args[:long_running] if args.key?(:long_running)
  @selector = args[:selector] if args.key?(:selector)
end