Class: Google::Apis::ServicenetworkingV1beta::MetricDescriptorMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

Additional annotations that can be used to guide the usage of a metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetricDescriptorMetadata

Returns a new instance of MetricDescriptorMetadata.



2987
2988
2989
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2987

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ingest_delayString

The delay of data points caused by ingestion. Data points older than this age are guaranteed to be ingested and available to be read, excluding data loss due to errors. Corresponds to the JSON property ingestDelay

Returns:

  • (String)


2967
2968
2969
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2967

def ingest_delay
  @ingest_delay
end

#launch_stageString

Deprecated. Must use the MetricDescriptor.launch_stage instead. Corresponds to the JSON property launchStage

Returns:

  • (String)


2972
2973
2974
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2972

def launch_stage
  @launch_stage
end

#sample_periodString

The sampling period of metric data points. For metrics which are written periodically, consecutive data points are stored at this time interval, excluding data loss due to errors. Metrics with a higher granularity have a smaller sampling period. Corresponds to the JSON property samplePeriod

Returns:

  • (String)


2980
2981
2982
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2980

def sample_period
  @sample_period
end

#time_series_resource_hierarchy_levelArray<String>

The scope of the timeseries data of the metric. Corresponds to the JSON property timeSeriesResourceHierarchyLevel

Returns:

  • (Array<String>)


2985
2986
2987
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2985

def time_series_resource_hierarchy_level
  @time_series_resource_hierarchy_level
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2992
2993
2994
2995
2996
2997
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 2992

def update!(**args)
  @ingest_delay = args[:ingest_delay] if args.key?(:ingest_delay)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @sample_period = args[:sample_period] if args.key?(:sample_period)
  @time_series_resource_hierarchy_level = args[:time_series_resource_hierarchy_level] if args.key?(:time_series_resource_hierarchy_level)
end