Class: Google::Apis::ServicenetworkingV1beta::MetricRule
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1beta::MetricRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb
Overview
Bind API methods to metrics. Binding a method to a metric causes that metric's configured quota behaviors to apply to the method call.
Instance Attribute Summary collapse
-
#metric_costs ⇒ Hash<String,Fixnum>
Metrics to update when the selected methods are called, and the associated cost applied to each metric.
-
#selector ⇒ String
Selects the methods to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetricRule
constructor
A new instance of MetricRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetricRule
Returns a new instance of MetricRule.
3052 3053 3054 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3052 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metric_costs ⇒ Hash<String,Fixnum>
Metrics to update when the selected methods are called, and the associated
cost applied to each metric. The key of the map is the metric name, and the
values are the amount increased for the metric against which the quota limits
are defined. The value must not be negative.
Corresponds to the JSON property metricCosts
3044 3045 3046 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3044 def metric_costs @metric_costs end |
#selector ⇒ String
Selects the methods to which this rule applies. Refer to selector for syntax
details.
Corresponds to the JSON property selector
3050 3051 3052 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3050 def selector @selector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3057 3058 3059 3060 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3057 def update!(**args) @metric_costs = args[:metric_costs] if args.key?(:metric_costs) @selector = args[:selector] if args.key?(:selector) end |