Class: Google::Apis::ServicenetworkingV1beta::PeeredDnsDomain

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

DNS domain suffix for which requests originating in the producer VPC network are resolved in the associated consumer VPC network.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PeeredDnsDomain

Returns a new instance of PeeredDnsDomain.



3502
3503
3504
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dns_suffixString

The DNS domain name suffix e.g. example.com.. Cloud DNS requires that a DNS suffix ends with a trailing dot. Corresponds to the JSON property dnsSuffix

Returns:

  • (String)


3492
3493
3494
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3492

def dns_suffix
  @dns_suffix
end

#nameString

Required. User assigned name for this resource. Must be unique within the consumer network. The name must be 1-63 characters long, must begin with a letter, end with a letter or digit, and only contain lowercase letters, digits or dashes. Corresponds to the JSON property name

Returns:

  • (String)


3500
3501
3502
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3500

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3507
3508
3509
3510
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3507

def update!(**args)
  @dns_suffix = args[:dns_suffix] if args.key?(:dns_suffix)
  @name = args[:name] if args.key?(:name)
end