Class: Google::Apis::ServicenetworkingV1beta::PeeredDnsDomain

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

DNS domain suffix for which requests originating in the producer VPC network are resolved in the associated consumer VPC network.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PeeredDnsDomain

Returns a new instance of PeeredDnsDomain.



3492
3493
3494
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3492

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dns_suffixString

The DNS domain name suffix e.g. example.com.. Cloud DNS requires that a DNS suffix ends with a trailing dot. Corresponds to the JSON property dnsSuffix

Returns:

  • (String)


3482
3483
3484
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3482

def dns_suffix
  @dns_suffix
end

#nameString

Required. User assigned name for this resource. Must be unique within the consumer network. The name must be 1-63 characters long, must begin with a letter, end with a letter or digit, and only contain lowercase letters, digits or dashes. Corresponds to the JSON property name

Returns:

  • (String)


3490
3491
3492
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3490

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3497
3498
3499
3500
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3497

def update!(**args)
  @dns_suffix = args[:dns_suffix] if args.key?(:dns_suffix)
  @name = args[:name] if args.key?(:name)
end