Class: Google::Apis::ServicenetworkingV1beta::PythonSettings
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1beta::PythonSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb
Overview
Settings for Python client libraries.
Instance Attribute Summary collapse
-
#common ⇒ Google::Apis::ServicenetworkingV1beta::CommonLanguageSettings
Required information for every language.
-
#experimental_features ⇒ Google::Apis::ServicenetworkingV1beta::ExperimentalFeatures
Experimental features to be included during client library generation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PythonSettings
constructor
A new instance of PythonSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PythonSettings
Returns a new instance of PythonSettings.
3699 3700 3701 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3699 def initialize(**args) update!(**args) end |
Instance Attribute Details
#common ⇒ Google::Apis::ServicenetworkingV1beta::CommonLanguageSettings
Required information for every language.
Corresponds to the JSON property common
3691 3692 3693 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3691 def common @common end |
#experimental_features ⇒ Google::Apis::ServicenetworkingV1beta::ExperimentalFeatures
Experimental features to be included during client library generation. These
fields will be deprecated once the feature graduates and is enabled by default.
Corresponds to the JSON property experimentalFeatures
3697 3698 3699 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3697 def experimental_features @experimental_features end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3704 3705 3706 3707 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3704 def update!(**args) @common = args[:common] if args.key?(:common) @experimental_features = args[:experimental_features] if args.key?(:experimental_features) end |