Class: Google::Apis::ServicenetworkingV1beta::PythonSettings
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1beta::PythonSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb
Overview
Settings for Python client libraries.
Instance Attribute Summary collapse
-
#common ⇒ Google::Apis::ServicenetworkingV1beta::CommonLanguageSettings
Required information for every language.
-
#experimental_features ⇒ Google::Apis::ServicenetworkingV1beta::ExperimentalFeatures
Experimental features to be included during client library generation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PythonSettings
constructor
A new instance of PythonSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PythonSettings
Returns a new instance of PythonSettings.
3656 3657 3658 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3656 def initialize(**args) update!(**args) end |
Instance Attribute Details
#common ⇒ Google::Apis::ServicenetworkingV1beta::CommonLanguageSettings
Required information for every language.
Corresponds to the JSON property common
3648 3649 3650 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3648 def common @common end |
#experimental_features ⇒ Google::Apis::ServicenetworkingV1beta::ExperimentalFeatures
Experimental features to be included during client library generation. These
fields will be deprecated once the feature graduates and is enabled by default.
Corresponds to the JSON property experimentalFeatures
3654 3655 3656 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3654 def experimental_features @experimental_features end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3661 3662 3663 3664 |
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3661 def update!(**args) @common = args[:common] if args.key?(:common) @experimental_features = args[:experimental_features] if args.key?(:experimental_features) end |