Class: Google::Apis::ServicenetworkingV1beta::QuotaLimit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

QuotaLimit defines a specific limit that applies over a specified duration for a limit type. There can be at most one limit for a duration and limit type combination defined within a QuotaGroup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuotaLimit

Returns a new instance of QuotaLimit.



3832
3833
3834
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3832

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_limitFixnum

Default number of tokens that can be consumed during the specified duration. This is the number of tokens assigned when a client application developer activates the service for his/her project. Specifying a value of 0 will block all requests. This can be used if you are provisioning quota to selected consumers and blocking others. Similarly, a value of -1 will indicate an unlimited quota. No other negative values are allowed. Used by group-based quotas only. Corresponds to the JSON property defaultLimit

Returns:

  • (Fixnum)


3759
3760
3761
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3759

def default_limit
  @default_limit
end

#descriptionString

Optional. User-visible, extended description for this quota limit. Should be used only when more context is needed to understand this limit than provided by the limit's display name (see: display_name). Corresponds to the JSON property description

Returns:

  • (String)


3766
3767
3768
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3766

def description
  @description
end

#display_nameString

User-visible display name for this limit. Optional. If not set, the UI will provide a default display name based on the quota configuration. This field can be used to override the default display name generated from the configuration. Corresponds to the JSON property displayName

Returns:

  • (String)


3774
3775
3776
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3774

def display_name
  @display_name
end

#durationString

Duration of this limit in textual notation. Must be "100s" or "1d". Used by group-based quotas only. Corresponds to the JSON property duration

Returns:

  • (String)


3780
3781
3782
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3780

def duration
  @duration
end

#free_tierFixnum

Free tier value displayed in the Developers Console for this limit. The free tier is the number of tokens that will be subtracted from the billed amount when billing is enabled. This field can only be set on a limit with duration " 1d", in a billable group; it is invalid on any other limit. If this field is not set, it defaults to 0, indicating that there is no free tier for this service. Used by group-based quotas only. Corresponds to the JSON property freeTier

Returns:

  • (Fixnum)


3790
3791
3792
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3790

def free_tier
  @free_tier
end

#max_limitFixnum

Maximum number of tokens that can be consumed during the specified duration. Client application developers can override the default limit up to this maximum. If specified, this value cannot be set to a value less than the default limit. If not specified, it is set to the default limit. To allow clients to apply overrides with no upper bound, set this to -1, indicating unlimited maximum quota. Used by group-based quotas only. Corresponds to the JSON property maxLimit

Returns:

  • (Fixnum)


3800
3801
3802
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3800

def max_limit
  @max_limit
end

#metricString

The name of the metric this quota limit applies to. The quota limits with the same metric will be checked together during runtime. The metric must be defined within the service config. Corresponds to the JSON property metric

Returns:

  • (String)


3807
3808
3809
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3807

def metric
  @metric
end

#nameString

Name of the quota limit. The name must be provided, and it must be unique within the service. The name can only include alphanumeric characters as well as '-'. The maximum length of the limit name is 64 characters. Corresponds to the JSON property name

Returns:

  • (String)


3814
3815
3816
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3814

def name
  @name
end

#unitString

Specify the unit of the quota limit. It uses the same syntax as MetricDescriptor.unit. The supported unit kinds are determined by the quota backend system. Here are some examples: * "1/min/project" for quota per minute per project. Note: the order of unit components is insignificant. The " 1" at the beginning is required to follow the metric unit syntax. Corresponds to the JSON property unit

Returns:

  • (String)


3823
3824
3825
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3823

def unit
  @unit
end

#valuesHash<String,Fixnum>

Tiered limit values. You must specify this as a key:value pair, with an integer value that is the maximum number of requests allowed for the specified unit. Currently only STANDARD is supported. Corresponds to the JSON property values

Returns:

  • (Hash<String,Fixnum>)


3830
3831
3832
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3830

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 3837

def update!(**args)
  @default_limit = args[:default_limit] if args.key?(:default_limit)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @duration = args[:duration] if args.key?(:duration)
  @free_tier = args[:free_tier] if args.key?(:free_tier)
  @max_limit = args[:max_limit] if args.key?(:max_limit)
  @metric = args[:metric] if args.key?(:metric)
  @name = args[:name] if args.key?(:name)
  @unit = args[:unit] if args.key?(:unit)
  @values = args[:values] if args.key?(:values)
end