Class: Google::Apis::ServicenetworkingV1beta::Subnetwork

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1beta/classes.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb,
lib/google/apis/servicenetworking_v1beta/representations.rb

Overview

Represents a subnet that was created or discovered by a private access management service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Subnetwork

Returns a new instance of Subnetwork.



4548
4549
4550
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4548

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_cidr_rangeString

Subnetwork CIDR range in 10.x.x.x/y format. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


4518
4519
4520
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4518

def ip_cidr_range
  @ip_cidr_range
end

#nameString

Subnetwork name. See https://cloud.google.com/compute/docs/vpc/ Corresponds to the JSON property name

Returns:

  • (String)


4523
4524
4525
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4523

def name
  @name
end

#networkString

In the Shared VPC host project, the VPC network that's peered with the consumer network. For example: projects/1234321/global/networks/host-network Corresponds to the JSON property network

Returns:

  • (String)


4529
4530
4531
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4529

def network
  @network
end

#outside_allocationBoolean Also known as: outside_allocation?

This is a discovered subnet that is not within the current consumer allocated ranges. Corresponds to the JSON property outsideAllocation

Returns:

  • (Boolean)


4535
4536
4537
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4535

def outside_allocation
  @outside_allocation
end

#regionString

GCP region where the subnetwork is located. Corresponds to the JSON property region

Returns:

  • (String)


4541
4542
4543
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4541

def region
  @region
end

#secondary_ip_rangesArray<Google::Apis::ServicenetworkingV1beta::SecondaryIpRange>

List of secondary IP ranges in this subnetwork. Corresponds to the JSON property secondaryIpRanges



4546
4547
4548
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4546

def secondary_ip_ranges
  @secondary_ip_ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4553
4554
4555
4556
4557
4558
4559
4560
# File 'lib/google/apis/servicenetworking_v1beta/classes.rb', line 4553

def update!(**args)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @outside_allocation = args[:outside_allocation] if args.key?(:outside_allocation)
  @region = args[:region] if args.key?(:region)
  @secondary_ip_ranges = args[:secondary_ip_ranges] if args.key?(:secondary_ip_ranges)
end